@@ -2,7 +2,6 @@ from .BubbleTrain import BubbleTrain
 from .Connector import Connector
 from .DraggablePanel import DraggablePanel
 from .DrawCanvas import DrawCanvas
-from .GridLayout import GridLayout
 from .TextInput import TextInput
 
 __all__ = [
@@ -10,6 +9,5 @@ __all__ = [
     "Connector",
     "DraggablePanel",
     "DrawCanvas",
-    "GridLayout",
     "TextInput"
 ]
\ No newline at end of file
